## 3.17.3.20240420 (2024-04-20)

Bump peewee to 3.17.3 and fix stubtest entries (#11787)

## 3.17.0.20240311 (2024-03-11)

Use PEP 570 syntax in third party stubs (#11554)

## 3.17.0.20240207 (2024-02-07)

Pin peewee more tightly for stubtest (#11372)

Fixes  #11367

## 3.17.0.20240118 (2024-01-18)

Added some typings to peewee stubs (#11284)

## 3.17.0.0 (2023-10-17)

Bump peewee to 3.17.* (#10895)

## 3.16.0.2 (2023-08-15)

Update peewee for 3.16.3 (#10580)

## 3.16.0.1 (2023-07-20)

Add an upstream_repository field to METADATA.toml (#10487)

Closes: #10478

## 3.16.0.0 (2023-02-28)

Update peewee stubs to v3.16 (#9827)

Bump peewee to 3.16.*

Release: https://pypi.org/pypi/peewee/3.16.0
Homepage: https://github.com/coleifer/peewee/
Diff: https://github.com/coleifer/peewee/compare/3.15.4...3.16.0

Stubsabot analysis of the diff between the two releases:
 - 0 public Python files have been added.
 - 0 files included in typeshed's stubs have been deleted.
 - 1 file included in typeshed's stubs has been modified or renamed: `peewee.py`.
 - Total lines of Python code added: 120.
 - Total lines of Python code deleted: 90.

Co-authored-by: Alex Waygood <Alex.Waygood@Gmail.com>

## 3.15.0.8 (2023-02-26)

Improve many `__(a)exit__` annotations (#9696)

## 3.15.0.7 (2023-02-21)

Stubtest settings: change `ignore_missing_stub` default to `false` (#9779)

If you're reading about this commit from an autogenerated changelog entry, this should have no user-visible impact on how the stubs are interpreted by a type checker; it's just an internal change to how typeshed's tests work.

## 3.15.0.6 (2023-02-15)

Use `typing_extensions.Self` instead of `_typeshed.Self` (#9702)

## 3.15.0.5 (2022-11-23)

Mark first argument of `__[get|set|del]attr__` as `str` (#9245)

## 3.15.0.4 (2022-11-13)

Make peewee stubs compatible with peewee 3.15.4 (#9176)

## 3.15.0.3 (2022-11-09)

All `__nonzero__` are methods that return `bool` (#9139)

## 3.15.0.2 (2022-11-09)

Annotate known magic-method return types (#9131)

## 3.15.0.1 (2022-11-08)

Fix and allow classes with missing metaclasses (#9136)

## 3.15.0.0 (2022-10-04)

Add auto-generated peewee stubs (#8834)

